@@ -3,9 +3,9 @@
 package App::abgrep;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-11-07'; # DATE
+our $DATE = '2020-11-08'; # DATE
 our $DIST = 'App-abgrep'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -43,12 +43,15 @@ _
         $meta->{examples} = [
             {
                 summary => 'Show lines that contain foo, bar, AND baz (in no particular order), but do not contain qux NOR quux',
-                'src' => q([[prog]] --all -e foo -e bar -e baz -e -qux -e -quux),
+                'src' => q([[prog]] --all --dash-prefix-inverts -e foo -e bar -e baz -e -qux -e -quux),
                 'src_plang' => 'bash',
                 'test' => 0,
                 'x.doc.show_result' => 0,
             },
         ];
+        $meta->{links} = [
+            {url=>'prog:grep-terms'},
+        ];
     },
     output_code => sub {
         my %args = @_;
@@ -109,7 +112,7 @@ App::abgrep - Print lines matching a pattern
 
 =head1 VERSION
 
-This document describes version 0.006 of App::abgrep (from Perl distribution App-abgrep), released on 2020-11-07.
+This document describes version 0.007 of App::abgrep (from Perl distribution App-abgrep), released on 2020-11-08.
 
 =head1 FUNCTIONS
 
